@@ -15,10 +15,14 @@ NB_VERSION = 4
 
 MD_RESPONSE_CELL_SOURCE = "_Type your answer here, replacing this text._"
 
-TEST_REGEX = r"(##\s*(hidden\s*)?test\s*##|#\s*(hidden\s*)?test)"
+BEGIN_TEST_CONFIG_REGEX = r'"""\s*#\s*BEGIN\s*TEST\s*CONFIG'
+END_TEST_CONFIG_REGEX = r'"""\s*#\s*END\s*TEST\s*CONFIG'
+TEST_REGEX = rf"(##\s*(hidden\s*)?test\s*##\s*|#\s*(hidden\s*)?test\s*|{BEGIN_TEST_CONFIG_REGEX})"
+# TEST_META_REGEX = r'("""\s*##\s*(begin\s*)?(hidden\s*)?(test\s*)?\s*(\r\n|\r|\n|.)*"""\s*##\s*(end\s*)?(hidden\s*)?(test\s*)?|"""\s*#\s*(begin\s*)?(hidden\s*)?(test\s*)?\s*(\r\n|\r|\n|.)*"""\s*#\s*(end\s*)?(hidden\s*)?(test\s*)?)'
 OTTR_TEST_NAME_REGEX = r'''(?:testthat::)?test_that\(['"]([A-Za-z0-9_]+)['"],'''
 MD_SOLUTION_REGEX = r"(<strong>|\*{2})solution:?(<\/strong>|\*{2})"
 SEED_REGEX = r"##\s*seed\s*##"
+IGNORE_REGEX = r"(##\s*ignore\s*##\s*|#\s*ignore\s*)"
 
 OTTR_TEST_FILE_TEMPLATE = Template("""\
 library(testthat)
