@@ -2,14 +2,16 @@
 Utilities for Otter Assign
 """
 
-import re
-import os
 import json
-import pprint
+import os
 import pathlib
+import pprint
+import re
+import shutil
 
-from glob import glob
 from contextlib import contextmanager
+from glob import glob
+from textwrap import indent
 
 from .constants import SEED_REGEX, BLOCK_QUOTE, IGNORE_REGEX
 
@@ -19,6 +21,7 @@ from ..generate import main as generate_autograder
 from ..generate.token import APIClient
 from ..utils import get_relpath, get_source
 
+
 class EmptyCellException(Exception):
     """
     Exception for empty cells to indicate deletion
@@ -154,13 +157,17 @@ def run_tests(nb_path, debug=False, seed=None, plugin_collection=None):
     """
     curr_dir = os.getcwd()
     os.chdir(nb_path.parent)
-    # print(os.getcwd())
+
     results = grade_notebook(
         nb_path.name, glob(os.path.join("tests", "*.py")), cwd=os.getcwd(), 
     	test_dir=os.path.join(os.getcwd(), "tests"), ignore_errors = not debug, seed=seed,
         plugin_collection=plugin_collection
     )
-    assert results.total == results.possible, "Some autograder tests failed:\n\n" + pprint.pformat(results, indent=2)
+
+    if results.total != results.possible:
+        raise RuntimeError(f"Some autograder tests failed in the autograder notebook:\n" + \
+            indent(results.summary(), '    '))
+
     os.chdir(curr_dir)
 
 def write_otter_config_file(master, result, assignment):
@@ -176,16 +183,7 @@ def write_otter_config_file(master, result, assignment):
     """
     config = {}
 
-    service = assignment.service
-    if service:
-        config.update({
-            "endpoint": service["endpoint"],
-            "auth": service.get("auth", "google"),
-            "assignment_id": service["assignment_id"],
-            "class_id": service["class_id"]
-        })
-
-    config["notebook"] = service.get('notebook', master.name)
+    config["notebook"] = master.name
     config["save_environment"] = assignment.save_environment
     config["ignore_modules"] = assignment.ignore_modules
 
@@ -232,6 +230,12 @@ def run_generate_autograder(result, assignment, gs_username, gs_password, plugin
 
         if not pdf_args.get('pagebreaks', True):
             generate_args['pagebreaks'] = False
+
+    # use temp tests dir
+    if assignment.is_python and not assignment.test_files and assignment._temp_test_dir is None:
+        raise RuntimeError("Failed to create temp tests directory for Otter Generate")
+    elif assignment.is_python and not assignment.test_files:
+        generate_cmd += ["-t", str(assignment._temp_test_dir)]
     
     if assignment.is_r:
         generate_cmd += ["-l", "r"]
@@ -277,6 +281,10 @@ def run_generate_autograder(result, assignment, gs_username, gs_password, plugin
     args = parser.parse_args(generate_cmd)
     generate_autograder(**vars(args), assignment=assignment, plugin_collection=plugin_collection)
 
+    # clean up temp tests dir
+    if assignment._temp_test_dir is not None:
+        shutil.rmtree(str(assignment._temp_test_dir))
+
     os.chdir(curr_dir)
 
 @contextmanager
