@@ -14,7 +14,7 @@ from contextlib import redirect_stdout, redirect_stderr
 from nbconvert.exporters import export
 from PyPDF2 import PdfFileMerger
 
-from .base_exporter import BaseExporter
+from .base_exporter import BaseExporter, NBCONVERT_6, TEMPLATE_DIR
 from .utils import notebook_pdf_generator
 
 class PDFViaHTMLExporter(BaseExporter):
@@ -32,7 +32,7 @@ class PDFViaHTMLExporter(BaseExporter):
     default_options = BaseExporter.default_options.copy()
     default_options.update({
         "save_html": False,
-        "template": "templates/via_html.tpl"
+        "template": "via_html"
     })
 
     @classmethod
@@ -44,8 +44,14 @@ class PDFViaHTMLExporter(BaseExporter):
 
         nb = cls.load_notebook(nb_path, filtering=options["filtering"], pagebreaks=options["pagebreaks"])
 
+        if NBCONVERT_6:
+            nbconvert.TemplateExporter.extra_template_basedirs = [TEMPLATE_DIR]
+            orig_template_name = nbconvert.TemplateExporter.template_name
+            nbconvert.TemplateExporter.template_name = options["template"]
+
         exporter = nbconvert.HTMLExporter()
-        exporter.template_file = pkg_resources.resource_filename(__name__, options["template"])
+        if not NBCONVERT_6:
+            exporter.template_file = os.path.join(TEMPLATE_DIR, options["template"] + ".tpl")
 
         if options["save_html"]:
             html, _ = export(exporter, nb)
@@ -72,3 +78,6 @@ class PDFViaHTMLExporter(BaseExporter):
             merger.append(output, import_bookmarks=False)
 
         merger.write(dest)
+
+        if NBCONVERT_6:
+            nbconvert.TemplateExporter.template_name = orig_template_name
