@@ -25,14 +25,14 @@ class GoogleSheetsGradeOverride(AbstractOtterPlugin):
     The google sheet should have the following format:
 
     =============== ================== =========== ======== ==============
-     Assignment ID   Email              Test Case   Points   PDF          
+     Assignment ID   Email              Question    Points   PDF          
     =============== ================== =========== ======== ==============
      123456          student@univ.edu   q1a - 1     1        false        
     =============== ================== =========== ======== ==============
 
     ``Assignment ID`` should be the ID of the assignment on Gradescope, ``Email`` should be the email
-    address corresponding to the student's Gradescope account, ``Test Case`` should be the name of
-    the test case, and ``Points`` should be the number of points that the student should be assigned.
+    address corresponding to the student's Gradescope account, ``Question`` should be the name of
+    the question, and ``Points`` should be the number of points that the student should be assigned.
     ``PDF`` should be ``false`` if the student's PDF should *not* be regenerated during this run of
     the autograder.
     """
@@ -47,20 +47,27 @@ class GoogleSheetsGradeOverride(AbstractOtterPlugin):
         Returns:
             ``pandas.core.frame.DataFrame``: the sheet as a dataframe
         """
-        oauth_json = self.plugin_config["service_account_credentials"]
-        with tempfile.NamedTemporaryFile(mode="w+", suffix=".json") as ntf:
-            json.dump(oauth_json, ntf)
-            ntf.seek(0)
+        try:
+            oauth_json = self.plugin_config["service_account_credentials"]
+            with tempfile.NamedTemporaryFile(mode="w+", suffix=".json") as ntf:
+                json.dump(oauth_json, ntf)
+                ntf.seek(0)
 
-            gc = gspread.service_account(filename=ntf.name)
-        
-        sheet_url = self.plugin_config["sheet_url"]
-        sheet = gc.open_by_url(sheet_url)
-        worksheet = sheet.get_worksheet(0)
-        data = worksheet.get_all_values()
-        colnames = data.pop(0)
+                gc = gspread.service_account(filename=ntf.name)
 
-        self._df = pd.DataFrame(data, columns=colnames)
+            sheet_url = self.plugin_config["sheet_url"]
+            sheet = gc.open_by_url(sheet_url)
+            worksheet = sheet.get_worksheet(0)
+            data = worksheet.get_all_values()
+            colnames = data.pop(0)
+
+            self._df = pd.DataFrame(data, columns=colnames)
+        except Exception as e:
+            if self.plugin_config.get("catch_api_error", True):
+                print(f"Error encountered while loading grade override sheet:\n{e}")
+                self._df = pd.DataFrame(columns=["Assignment ID", "Email", "Question", "Points", "PDF"])
+            else:
+                raise e
 
     @property
     def df(self):
@@ -86,7 +93,7 @@ class GoogleSheetsGradeOverride(AbstractOtterPlugin):
                 (df["Assignment ID"] == str(self.submission_metadata["assignment"]["id"]))
             ]
             for _, row in df.iterrows():
-                results.update_result(row["Test Case"], score=row["Points"])
+                results.update_score(row["Question"], float(row["Points"]))
 
     def during_generate(self, otter_config, assignment):
         """
