@@ -7,6 +7,7 @@ DEFAULT_OPTIONS = {
     "points_possible": None,
     "show_stdout": False,
     "show_hidden": False,
+    "show_all_public": False,
     "seed": None,
     "grade_from_log": False,
     "serialized_variables": {},
@@ -15,8 +16,8 @@ DEFAULT_OPTIONS = {
     "token": None,
     "course_id": 'None',
     "assignment_id": 'None',
-    "filtering": True,
-    "pagebreaks": True,
+    "filtering": False,
+    "pagebreaks": False,
     "debug": False,
     "autograder_dir": '/autograder',
     "lang": 'python',
@@ -26,5 +27,6 @@ DEFAULT_OPTIONS = {
     "plugins": [],
     "logo": True,
     "print_summary": True,
+    "print_score": True,
     "zips": False,
 }
