@@ -44,10 +44,10 @@ class TestGrade(TestCase):
             lines = f.readlines()
 
             idx = max([i if "ARG" in lines[i] else -1 for i in range(len(lines))])
-            lines.insert(idx + 1, "ADD . /home/otter-grader")
+            lines.insert(idx + 1, "ADD . /home/otter-grader\n")
 
             f.seek(0)
-            f.write("\n".join(lines))
+            f.write("".join(lines))
         
     def setUp(self):
         """
